# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Series(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'frequency': 'str',
        'ticker': 'str',
        'title': 'str'
    }

    attribute_map = {
        'frequency': 'frequency',
        'ticker': 'ticker',
        'title': 'title'
    }

    def __init__(self, frequency=None, ticker=None, title=None):  # noqa: E501
        """Series - a model defined in Swagger"""  # noqa: E501
        self._frequency = None
        self._ticker = None
        self._title = None
        self.discriminator = None
        self.frequency = frequency
        self.ticker = ticker
        self.title = title

    @property
    def frequency(self):
        """Gets the frequency of this Series.  # noqa: E501

        Description of the frequency of the series. There is no fixed value set here, but will be something human-readable like: weekly, daily, one-off.  # noqa: E501

        :return: The frequency of this Series.  # noqa: E501
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this Series.

        Description of the frequency of the series. There is no fixed value set here, but will be something human-readable like: weekly, daily, one-off.  # noqa: E501

        :param frequency: The frequency of this Series.  # noqa: E501
        :type: str
        """
        if frequency is None:
            raise ValueError("Invalid value for `frequency`, must not be `None`")  # noqa: E501

        self._frequency = frequency

    @property
    def ticker(self):
        """Gets the ticker of this Series.  # noqa: E501

        Ticker that identifies this series.  # noqa: E501

        :return: The ticker of this Series.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this Series.

        Ticker that identifies this series.  # noqa: E501

        :param ticker: The ticker of this Series.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def title(self):
        """Gets the title of this Series.  # noqa: E501

        Title describing the series. For full context use you should use this field with the title field of the events belonging to this series.  # noqa: E501

        :return: The title of this Series.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Series.

        Title describing the series. For full context use you should use this field with the title field of the events belonging to this series.  # noqa: E501

        :param title: The title of this Series.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Series, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Series):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kalshi_python
from kalshi_python.api.portfolio_api import PortfolioApi  # noqa: E501
from kalshi_python.rest import ApiException


class TestPortfolioApi(unittest.TestCase):
    """PortfolioApi unit test stubs"""

    def setUp(self):
        self.api = PortfolioApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_batch_cancel_orders(self):
        """Test case for batch_cancel_orders

        BatchCancelOrders  # noqa: E501
        """
        pass

    def test_batch_create_orders(self):
        """Test case for batch_create_orders

        BatchCreateOrders  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        CancelOrder  # noqa: E501
        """
        pass

    def test_create_order(self):
        """Test case for create_order

        CreateOrder  # noqa: E501
        """
        pass

    def test_decrease_order(self):
        """Test case for decrease_order

        DecreaseOrder  # noqa: E501
        """
        pass

    def test_get_balance(self):
        """Test case for get_balance

        GetBalance  # noqa: E501
        """
        pass

    def test_get_fills(self):
        """Test case for get_fills

        GetFills  # noqa: E501
        """
        pass

    def test_get_order(self):
        """Test case for get_order

        GetOrder  # noqa: E501
        """
        pass

    def test_get_orders(self):
        """Test case for get_orders

        GetOrders  # noqa: E501
        """
        pass

    def test_get_portfolio_settlements(self):
        """Test case for get_portfolio_settlements

        GetPortfolioSettlements  # noqa: E501
        """
        pass

    def test_get_positions(self):
        """Test case for get_positions

        GetPositions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MarketStatsPoint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'no_ask': 'Cent',
        'no_bid': 'Cent',
        'open_interest': 'int',
        'ts': 'int',
        'volume': 'int',
        'yes_ask': 'Cent',
        'yes_bid': 'Cent',
        'yes_price': 'Cent'
    }

    attribute_map = {
        'no_ask': 'no_ask',
        'no_bid': 'no_bid',
        'open_interest': 'open_interest',
        'ts': 'ts',
        'volume': 'volume',
        'yes_ask': 'yes_ask',
        'yes_bid': 'yes_bid',
        'yes_price': 'yes_price'
    }

    def __init__(self, no_ask=None, no_bid=None, open_interest=None, ts=None, volume=None, yes_ask=None, yes_bid=None, yes_price=None):  # noqa: E501
        """MarketStatsPoint - a model defined in Swagger"""  # noqa: E501
        self._no_ask = None
        self._no_bid = None
        self._open_interest = None
        self._ts = None
        self._volume = None
        self._yes_ask = None
        self._yes_bid = None
        self._yes_price = None
        self.discriminator = None
        self.no_ask = no_ask
        self.no_bid = no_bid
        self.open_interest = open_interest
        self.ts = ts
        self.volume = volume
        self.yes_ask = yes_ask
        self.yes_bid = yes_bid
        self.yes_price = yes_price

    @property
    def no_ask(self):
        """Gets the no_ask of this MarketStatsPoint.  # noqa: E501


        :return: The no_ask of this MarketStatsPoint.  # noqa: E501
        :rtype: Cent
        """
        return self._no_ask

    @no_ask.setter
    def no_ask(self, no_ask):
        """Sets the no_ask of this MarketStatsPoint.


        :param no_ask: The no_ask of this MarketStatsPoint.  # noqa: E501
        :type: Cent
        """
        if no_ask is None:
            raise ValueError("Invalid value for `no_ask`, must not be `None`")  # noqa: E501

        self._no_ask = no_ask

    @property
    def no_bid(self):
        """Gets the no_bid of this MarketStatsPoint.  # noqa: E501


        :return: The no_bid of this MarketStatsPoint.  # noqa: E501
        :rtype: Cent
        """
        return self._no_bid

    @no_bid.setter
    def no_bid(self, no_bid):
        """Sets the no_bid of this MarketStatsPoint.


        :param no_bid: The no_bid of this MarketStatsPoint.  # noqa: E501
        :type: Cent
        """
        if no_bid is None:
            raise ValueError("Invalid value for `no_bid`, must not be `None`")  # noqa: E501

        self._no_bid = no_bid

    @property
    def open_interest(self):
        """Gets the open_interest of this MarketStatsPoint.  # noqa: E501

        Number of contracts bought on the market by the timestamp in the request (ts) disconsidering netting.  # noqa: E501

        :return: The open_interest of this MarketStatsPoint.  # noqa: E501
        :rtype: int
        """
        return self._open_interest

    @open_interest.setter
    def open_interest(self, open_interest):
        """Sets the open_interest of this MarketStatsPoint.

        Number of contracts bought on the market by the timestamp in the request (ts) disconsidering netting.  # noqa: E501

        :param open_interest: The open_interest of this MarketStatsPoint.  # noqa: E501
        :type: int
        """
        if open_interest is None:
            raise ValueError("Invalid value for `open_interest`, must not be `None`")  # noqa: E501

        self._open_interest = open_interest

    @property
    def ts(self):
        """Gets the ts of this MarketStatsPoint.  # noqa: E501

        Unix timestamp for the current statistics entry.  # noqa: E501

        :return: The ts of this MarketStatsPoint.  # noqa: E501
        :rtype: int
        """
        return self._ts

    @ts.setter
    def ts(self, ts):
        """Sets the ts of this MarketStatsPoint.

        Unix timestamp for the current statistics entry.  # noqa: E501

        :param ts: The ts of this MarketStatsPoint.  # noqa: E501
        :type: int
        """
        if ts is None:
            raise ValueError("Invalid value for `ts`, must not be `None`")  # noqa: E501

        self._ts = ts

    @property
    def volume(self):
        """Gets the volume of this MarketStatsPoint.  # noqa: E501

        Number of contracts bought on the market by the timestamp in the request (ts).  # noqa: E501

        :return: The volume of this MarketStatsPoint.  # noqa: E501
        :rtype: int
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this MarketStatsPoint.

        Number of contracts bought on the market by the timestamp in the request (ts).  # noqa: E501

        :param volume: The volume of this MarketStatsPoint.  # noqa: E501
        :type: int
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def yes_ask(self):
        """Gets the yes_ask of this MarketStatsPoint.  # noqa: E501


        :return: The yes_ask of this MarketStatsPoint.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_ask

    @yes_ask.setter
    def yes_ask(self, yes_ask):
        """Sets the yes_ask of this MarketStatsPoint.


        :param yes_ask: The yes_ask of this MarketStatsPoint.  # noqa: E501
        :type: Cent
        """
        if yes_ask is None:
            raise ValueError("Invalid value for `yes_ask`, must not be `None`")  # noqa: E501

        self._yes_ask = yes_ask

    @property
    def yes_bid(self):
        """Gets the yes_bid of this MarketStatsPoint.  # noqa: E501


        :return: The yes_bid of this MarketStatsPoint.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_bid

    @yes_bid.setter
    def yes_bid(self, yes_bid):
        """Sets the yes_bid of this MarketStatsPoint.


        :param yes_bid: The yes_bid of this MarketStatsPoint.  # noqa: E501
        :type: Cent
        """
        if yes_bid is None:
            raise ValueError("Invalid value for `yes_bid`, must not be `None`")  # noqa: E501

        self._yes_bid = yes_bid

    @property
    def yes_price(self):
        """Gets the yes_price of this MarketStatsPoint.  # noqa: E501


        :return: The yes_price of this MarketStatsPoint.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_price

    @yes_price.setter
    def yes_price(self, yes_price):
        """Sets the yes_price of this MarketStatsPoint.


        :param yes_price: The yes_price of this MarketStatsPoint.  # noqa: E501
        :type: Cent
        """
        if yes_price is None:
            raise ValueError("Invalid value for `yes_price`, must not be `None`")  # noqa: E501

        self._yes_price = yes_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MarketStatsPoint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarketStatsPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

from pathlib import Path
NAME = "kalshi_python"
VERSION = "1.3.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name=NAME,
    version=VERSION,
    description="Kalshi Trade API",
    author_email="support@kalshi.com",
    url="https://github.com/Kalshi/kalshi-python",
    keywords=["Swagger", "Kalshi Trade API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description=long_description
)



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'event_ticker': 'str',
        'mutually_exclusive': 'bool',
        'series_ticker': 'str',
        'strike_date': 'OutputTime',
        'strike_period': 'str',
        'sub_title': 'str',
        'title': 'str'
    }

    attribute_map = {
        'category': 'category',
        'event_ticker': 'event_ticker',
        'mutually_exclusive': 'mutually_exclusive',
        'series_ticker': 'series_ticker',
        'strike_date': 'strike_date',
        'strike_period': 'strike_period',
        'sub_title': 'sub_title',
        'title': 'title'
    }

    def __init__(self, category=None, event_ticker=None, mutually_exclusive=None, series_ticker=None, strike_date=None, strike_period=None, sub_title=None, title=None):  # noqa: E501
        """EventData - a model defined in Swagger"""  # noqa: E501
        self._category = None
        self._event_ticker = None
        self._mutually_exclusive = None
        self._series_ticker = None
        self._strike_date = None
        self._strike_period = None
        self._sub_title = None
        self._title = None
        self.discriminator = None
        self.category = category
        self.event_ticker = event_ticker
        self.mutually_exclusive = mutually_exclusive
        self.series_ticker = series_ticker
        if strike_date is not None:
            self.strike_date = strike_date
        if strike_period is not None:
            self.strike_period = strike_period
        self.sub_title = sub_title
        self.title = title

    @property
    def category(self):
        """Gets the category of this EventData.  # noqa: E501

        Event category.  # noqa: E501

        :return: The category of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this EventData.

        Event category.  # noqa: E501

        :param category: The category of this EventData.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def event_ticker(self):
        """Gets the event_ticker of this EventData.  # noqa: E501

        Unique identifier for events.  # noqa: E501

        :return: The event_ticker of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._event_ticker

    @event_ticker.setter
    def event_ticker(self, event_ticker):
        """Sets the event_ticker of this EventData.

        Unique identifier for events.  # noqa: E501

        :param event_ticker: The event_ticker of this EventData.  # noqa: E501
        :type: str
        """
        if event_ticker is None:
            raise ValueError("Invalid value for `event_ticker`, must not be `None`")  # noqa: E501

        self._event_ticker = event_ticker

    @property
    def mutually_exclusive(self):
        """Gets the mutually_exclusive of this EventData.  # noqa: E501

        If true then the event is mutually exclusive.  # noqa: E501

        :return: The mutually_exclusive of this EventData.  # noqa: E501
        :rtype: bool
        """
        return self._mutually_exclusive

    @mutually_exclusive.setter
    def mutually_exclusive(self, mutually_exclusive):
        """Sets the mutually_exclusive of this EventData.

        If true then the event is mutually exclusive.  # noqa: E501

        :param mutually_exclusive: The mutually_exclusive of this EventData.  # noqa: E501
        :type: bool
        """
        if mutually_exclusive is None:
            raise ValueError("Invalid value for `mutually_exclusive`, must not be `None`")  # noqa: E501

        self._mutually_exclusive = mutually_exclusive

    @property
    def series_ticker(self):
        """Gets the series_ticker of this EventData.  # noqa: E501

        Unique identifier for series.  # noqa: E501

        :return: The series_ticker of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._series_ticker

    @series_ticker.setter
    def series_ticker(self, series_ticker):
        """Sets the series_ticker of this EventData.

        Unique identifier for series.  # noqa: E501

        :param series_ticker: The series_ticker of this EventData.  # noqa: E501
        :type: str
        """
        if series_ticker is None:
            raise ValueError("Invalid value for `series_ticker`, must not be `None`")  # noqa: E501

        self._series_ticker = series_ticker

    @property
    def strike_date(self):
        """Gets the strike_date of this EventData.  # noqa: E501


        :return: The strike_date of this EventData.  # noqa: E501
        :rtype: OutputTime
        """
        return self._strike_date

    @strike_date.setter
    def strike_date(self, strike_date):
        """Sets the strike_date of this EventData.


        :param strike_date: The strike_date of this EventData.  # noqa: E501
        :type: OutputTime
        """

        self._strike_date = strike_date

    @property
    def strike_period(self):
        """Gets the strike_period of this EventData.  # noqa: E501

        The strike period for this event. This will be filled when the event strike is not a date. If it is a date then the 'strike_date' field should be filled instead.  # noqa: E501

        :return: The strike_period of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._strike_period

    @strike_period.setter
    def strike_period(self, strike_period):
        """Sets the strike_period of this EventData.

        The strike period for this event. This will be filled when the event strike is not a date. If it is a date then the 'strike_date' field should be filled instead.  # noqa: E501

        :param strike_period: The strike_period of this EventData.  # noqa: E501
        :type: str
        """

        self._strike_period = strike_period

    @property
    def sub_title(self):
        """Gets the sub_title of this EventData.  # noqa: E501

        Shortened title.  # noqa: E501

        :return: The sub_title of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._sub_title

    @sub_title.setter
    def sub_title(self, sub_title):
        """Sets the sub_title of this EventData.

        Shortened title.  # noqa: E501

        :param sub_title: The sub_title of this EventData.  # noqa: E501
        :type: str
        """
        if sub_title is None:
            raise ValueError("Invalid value for `sub_title`, must not be `None`")  # noqa: E501

        self._sub_title = sub_title

    @property
    def title(self):
        """Gets the title of this EventData.  # noqa: E501

        Event title.  # noqa: E501

        :return: The title of this EventData.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EventData.

        Event title.  # noqa: E501

        :param title: The title of this EventData.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Order(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action': 'str',
        'client_order_id': 'str',
        'close_cancel_count': 'int',
        'created_time': 'OutputTime',
        'decrease_count': 'int',
        'expiration_time': 'OutputTime',
        'fcc_cancel_count': 'int',
        'last_update_time': 'OutputTime',
        'maker_fill_count': 'int',
        'no_price': 'Cent',
        'order_id': 'str',
        'place_count': 'int',
        'queue_position': 'int',
        'remaining_count': 'int',
        'side': 'str',
        'status': 'OrderStatus',
        'taker_fees': 'Cent',
        'taker_fill_cost': 'Cent',
        'taker_fill_count': 'int',
        'ticker': 'str',
        'type': 'OrderType',
        'user_id': 'str',
        'yes_price': 'Cent'
    }

    attribute_map = {
        'action': 'action',
        'client_order_id': 'client_order_id',
        'close_cancel_count': 'close_cancel_count',
        'created_time': 'created_time',
        'decrease_count': 'decrease_count',
        'expiration_time': 'expiration_time',
        'fcc_cancel_count': 'fcc_cancel_count',
        'last_update_time': 'last_update_time',
        'maker_fill_count': 'maker_fill_count',
        'no_price': 'no_price',
        'order_id': 'order_id',
        'place_count': 'place_count',
        'queue_position': 'queue_position',
        'remaining_count': 'remaining_count',
        'side': 'side',
        'status': 'status',
        'taker_fees': 'taker_fees',
        'taker_fill_cost': 'taker_fill_cost',
        'taker_fill_count': 'taker_fill_count',
        'ticker': 'ticker',
        'type': 'type',
        'user_id': 'user_id',
        'yes_price': 'yes_price'
    }

    def __init__(self, action=None, client_order_id=None, close_cancel_count=None, created_time=None, decrease_count=None, expiration_time=None, fcc_cancel_count=None, last_update_time=None, maker_fill_count=None, no_price=None, order_id=None, place_count=None, queue_position=None, remaining_count=None, side=None, status=None, taker_fees=None, taker_fill_cost=None, taker_fill_count=None, ticker=None, type=None, user_id=None, yes_price=None):  # noqa: E501
        """Order - a model defined in Swagger"""  # noqa: E501
        self._action = None
        self._client_order_id = None
        self._close_cancel_count = None
        self._created_time = None
        self._decrease_count = None
        self._expiration_time = None
        self._fcc_cancel_count = None
        self._last_update_time = None
        self._maker_fill_count = None
        self._no_price = None
        self._order_id = None
        self._place_count = None
        self._queue_position = None
        self._remaining_count = None
        self._side = None
        self._status = None
        self._taker_fees = None
        self._taker_fill_cost = None
        self._taker_fill_count = None
        self._ticker = None
        self._type = None
        self._user_id = None
        self._yes_price = None
        self.discriminator = None
        self.action = action
        self.client_order_id = client_order_id
        if close_cancel_count is not None:
            self.close_cancel_count = close_cancel_count
        if created_time is not None:
            self.created_time = created_time
        if decrease_count is not None:
            self.decrease_count = decrease_count
        if expiration_time is not None:
            self.expiration_time = expiration_time
        if fcc_cancel_count is not None:
            self.fcc_cancel_count = fcc_cancel_count
        if last_update_time is not None:
            self.last_update_time = last_update_time
        if maker_fill_count is not None:
            self.maker_fill_count = maker_fill_count
        self.no_price = no_price
        if order_id is not None:
            self.order_id = order_id
        if place_count is not None:
            self.place_count = place_count
        if queue_position is not None:
            self.queue_position = queue_position
        if remaining_count is not None:
            self.remaining_count = remaining_count
        self.side = side
        self.status = status
        if taker_fees is not None:
            self.taker_fees = taker_fees
        if taker_fill_cost is not None:
            self.taker_fill_cost = taker_fill_cost
        if taker_fill_count is not None:
            self.taker_fill_count = taker_fill_count
        self.ticker = ticker
        self.type = type
        if user_id is not None:
            self.user_id = user_id
        self.yes_price = yes_price

    @property
    def action(self):
        """Gets the action of this Order.  # noqa: E501

        Representing trade action; currently supports buy and sell.  # noqa: E501

        :return: The action of this Order.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this Order.

        Representing trade action; currently supports buy and sell.  # noqa: E501

        :param action: The action of this Order.  # noqa: E501
        :type: str
        """
        if action is None:
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501
        allowed_values = ["buy", "sell", ""]  # noqa: E501
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def client_order_id(self):
        """Gets the client_order_id of this Order.  # noqa: E501

        Optional unique identifier for order placement.  # noqa: E501

        :return: The client_order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._client_order_id

    @client_order_id.setter
    def client_order_id(self, client_order_id):
        """Sets the client_order_id of this Order.

        Optional unique identifier for order placement.  # noqa: E501

        :param client_order_id: The client_order_id of this Order.  # noqa: E501
        :type: str
        """
        if client_order_id is None:
            raise ValueError("Invalid value for `client_order_id`, must not be `None`")  # noqa: E501

        self._client_order_id = client_order_id

    @property
    def close_cancel_count(self):
        """Gets the close_cancel_count of this Order.  # noqa: E501

        The size of resting orders canceled because of market close (contract units).  # noqa: E501

        :return: The close_cancel_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._close_cancel_count

    @close_cancel_count.setter
    def close_cancel_count(self, close_cancel_count):
        """Sets the close_cancel_count of this Order.

        The size of resting orders canceled because of market close (contract units).  # noqa: E501

        :param close_cancel_count: The close_cancel_count of this Order.  # noqa: E501
        :type: int
        """

        self._close_cancel_count = close_cancel_count

    @property
    def created_time(self):
        """Gets the created_time of this Order.  # noqa: E501


        :return: The created_time of this Order.  # noqa: E501
        :rtype: OutputTime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this Order.


        :param created_time: The created_time of this Order.  # noqa: E501
        :type: OutputTime
        """

        self._created_time = created_time

    @property
    def decrease_count(self):
        """Gets the decrease_count of this Order.  # noqa: E501

        The reduction in the size of resting for orders (contract units).  # noqa: E501

        :return: The decrease_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._decrease_count

    @decrease_count.setter
    def decrease_count(self, decrease_count):
        """Sets the decrease_count of this Order.

        The reduction in the size of resting for orders (contract units).  # noqa: E501

        :param decrease_count: The decrease_count of this Order.  # noqa: E501
        :type: int
        """

        self._decrease_count = decrease_count

    @property
    def expiration_time(self):
        """Gets the expiration_time of this Order.  # noqa: E501


        :return: The expiration_time of this Order.  # noqa: E501
        :rtype: OutputTime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this Order.


        :param expiration_time: The expiration_time of this Order.  # noqa: E501
        :type: OutputTime
        """

        self._expiration_time = expiration_time

    @property
    def fcc_cancel_count(self):
        """Gets the fcc_cancel_count of this Order.  # noqa: E501

        The size of resting contracts canceled because of exchange operations (contract units).  # noqa: E501

        :return: The fcc_cancel_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._fcc_cancel_count

    @fcc_cancel_count.setter
    def fcc_cancel_count(self, fcc_cancel_count):
        """Sets the fcc_cancel_count of this Order.

        The size of resting contracts canceled because of exchange operations (contract units).  # noqa: E501

        :param fcc_cancel_count: The fcc_cancel_count of this Order.  # noqa: E501
        :type: int
        """

        self._fcc_cancel_count = fcc_cancel_count

    @property
    def last_update_time(self):
        """Gets the last_update_time of this Order.  # noqa: E501


        :return: The last_update_time of this Order.  # noqa: E501
        :rtype: OutputTime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this Order.


        :param last_update_time: The last_update_time of this Order.  # noqa: E501
        :type: OutputTime
        """

        self._last_update_time = last_update_time

    @property
    def maker_fill_count(self):
        """Gets the maker_fill_count of this Order.  # noqa: E501

        The size of filled maker orders (contract units).  # noqa: E501

        :return: The maker_fill_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._maker_fill_count

    @maker_fill_count.setter
    def maker_fill_count(self, maker_fill_count):
        """Sets the maker_fill_count of this Order.

        The size of filled maker orders (contract units).  # noqa: E501

        :param maker_fill_count: The maker_fill_count of this Order.  # noqa: E501
        :type: int
        """

        self._maker_fill_count = maker_fill_count

    @property
    def no_price(self):
        """Gets the no_price of this Order.  # noqa: E501


        :return: The no_price of this Order.  # noqa: E501
        :rtype: Cent
        """
        return self._no_price

    @no_price.setter
    def no_price(self, no_price):
        """Sets the no_price of this Order.


        :param no_price: The no_price of this Order.  # noqa: E501
        :type: Cent
        """
        if no_price is None:
            raise ValueError("Invalid value for `no_price`, must not be `None`")  # noqa: E501

        self._no_price = no_price

    @property
    def order_id(self):
        """Gets the order_id of this Order.  # noqa: E501


        :return: The order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this Order.


        :param order_id: The order_id of this Order.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def place_count(self):
        """Gets the place_count of this Order.  # noqa: E501

        the size of placed maker orders (contract units).  # noqa: E501

        :return: The place_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._place_count

    @place_count.setter
    def place_count(self, place_count):
        """Sets the place_count of this Order.

        the size of placed maker orders (contract units).  # noqa: E501

        :param place_count: The place_count of this Order.  # noqa: E501
        :type: int
        """

        self._place_count = place_count

    @property
    def queue_position(self):
        """Gets the queue_position of this Order.  # noqa: E501

        Position in the priority queue at a given price level  # noqa: E501

        :return: The queue_position of this Order.  # noqa: E501
        :rtype: int
        """
        return self._queue_position

    @queue_position.setter
    def queue_position(self, queue_position):
        """Sets the queue_position of this Order.

        Position in the priority queue at a given price level  # noqa: E501

        :param queue_position: The queue_position of this Order.  # noqa: E501
        :type: int
        """

        self._queue_position = queue_position

    @property
    def remaining_count(self):
        """Gets the remaining_count of this Order.  # noqa: E501

        The size of the remaining resting orders (contract units).  # noqa: E501

        :return: The remaining_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._remaining_count

    @remaining_count.setter
    def remaining_count(self, remaining_count):
        """Sets the remaining_count of this Order.

        The size of the remaining resting orders (contract units).  # noqa: E501

        :param remaining_count: The remaining_count of this Order.  # noqa: E501
        :type: int
        """

        self._remaining_count = remaining_count

    @property
    def side(self):
        """Gets the side of this Order.  # noqa: E501

        Representing direction of the order; currently supports yes and no.  # noqa: E501

        :return: The side of this Order.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this Order.

        Representing direction of the order; currently supports yes and no.  # noqa: E501

        :param side: The side of this Order.  # noqa: E501
        :type: str
        """
        if side is None:
            raise ValueError("Invalid value for `side`, must not be `None`")  # noqa: E501
        allowed_values = ["yes", "no", "invalid", ""]  # noqa: E501
        if side not in allowed_values:
            raise ValueError(
                "Invalid value for `side` ({0}), must be one of {1}"  # noqa: E501
                .format(side, allowed_values)
            )

        self._side = side

    @property
    def status(self):
        """Gets the status of this Order.  # noqa: E501


        :return: The status of this Order.  # noqa: E501
        :rtype: OrderStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Order.


        :param status: The status of this Order.  # noqa: E501
        :type: OrderStatus
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def taker_fees(self):
        """Gets the taker_fees of this Order.  # noqa: E501


        :return: The taker_fees of this Order.  # noqa: E501
        :rtype: Cent
        """
        return self._taker_fees

    @taker_fees.setter
    def taker_fees(self, taker_fees):
        """Sets the taker_fees of this Order.


        :param taker_fees: The taker_fees of this Order.  # noqa: E501
        :type: Cent
        """

        self._taker_fees = taker_fees

    @property
    def taker_fill_cost(self):
        """Gets the taker_fill_cost of this Order.  # noqa: E501


        :return: The taker_fill_cost of this Order.  # noqa: E501
        :rtype: Cent
        """
        return self._taker_fill_cost

    @taker_fill_cost.setter
    def taker_fill_cost(self, taker_fill_cost):
        """Sets the taker_fill_cost of this Order.


        :param taker_fill_cost: The taker_fill_cost of this Order.  # noqa: E501
        :type: Cent
        """

        self._taker_fill_cost = taker_fill_cost

    @property
    def taker_fill_count(self):
        """Gets the taker_fill_count of this Order.  # noqa: E501

        The size of filled taker orders (contract units)  # noqa: E501

        :return: The taker_fill_count of this Order.  # noqa: E501
        :rtype: int
        """
        return self._taker_fill_count

    @taker_fill_count.setter
    def taker_fill_count(self, taker_fill_count):
        """Sets the taker_fill_count of this Order.

        The size of filled taker orders (contract units)  # noqa: E501

        :param taker_fill_count: The taker_fill_count of this Order.  # noqa: E501
        :type: int
        """

        self._taker_fill_count = taker_fill_count

    @property
    def ticker(self):
        """Gets the ticker of this Order.  # noqa: E501

        Unique identifier for markets.  # noqa: E501

        :return: The ticker of this Order.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this Order.

        Unique identifier for markets.  # noqa: E501

        :param ticker: The ticker of this Order.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def type(self):
        """Gets the type of this Order.  # noqa: E501


        :return: The type of this Order.  # noqa: E501
        :rtype: OrderType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Order.


        :param type: The type of this Order.  # noqa: E501
        :type: OrderType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def user_id(self):
        """Gets the user_id of this Order.  # noqa: E501


        :return: The user_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Order.


        :param user_id: The user_id of this Order.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def yes_price(self):
        """Gets the yes_price of this Order.  # noqa: E501


        :return: The yes_price of this Order.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_price

    @yes_price.setter
    def yes_price(self, yes_price):
        """Sets the yes_price of this Order.


        :param yes_price: The yes_price of this Order.  # noqa: E501
        :type: Cent
        """
        if yes_price is None:
            raise ValueError("Invalid value for `yes_price`, must not be `None`")  # noqa: E501

        self._yes_price = yes_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Order, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kalshi_python.api.auth_api import AuthApi
from kalshi_python.api.exchange_api import ExchangeApi
from kalshi_python.api.market_api import MarketApi
from kalshi_python.api.portfolio_api import PortfolioApi
